@@ -430,14 +430,13 @@ classification.colid <- function(id, start = NULL, checklist = NULL,
     } else {
       url <- make_url(checklist)
       args <- tc(list(id = x, response = "full", start = start))
-      out <- tax_GET(url, query = args, opts = callopts)
-      tt <- xml2::read_xml(out$parse("UTF-8"))
-      out <- search_col_classification_df(tt)
+      res <- tax_GET(url, query = args, opts = callopts)
+      out <- search_col_classification_df(res)
       # add query-ied taxon
       out <- rbind(out, c(
-        xml2::xml_text(xml2::xml_find_first(tt, "//result/name")),
-        xml2::xml_text(xml2::xml_find_first(tt, "//result/rank")),
-        xml2::xml_text(xml2::xml_find_first(tt, "//result/id"))))
+        xml2::xml_text(xml2::xml_find_first(res, "//result/name")),
+        xml2::xml_text(xml2::xml_find_first(res, "//result/rank")),
+        xml2::xml_text(xml2::xml_find_first(res, "//result/id"))))
       # Optionally return id of lineage
       if (!return_id) out <- out[, c('name', 'rank')]
       out$rank <- tolower(out$rank)
