@@ -10,6 +10,9 @@ pluck <- function(x, name, type) {
   }
 }
 
+# pluck with unname
+pluck_un <- function(x, name, type) unname(pluck(x, name, type))
+
 collapse <- function(x, fxn, class, match=TRUE, ...) {
   tmp <- lapply(x, fxn, ...)
   if (match) {
@@ -191,6 +194,15 @@ assert <- function(x, y) {
   }
 }
 
+assert_state <- function(x, y) {
+  if (!is.null(x) && inherits(x, "taxon_state")) {
+    if (x$class != y) {
+      stop("taxon_state class must match the get_* function called ",
+        call. = FALSE)
+    }
+  }
+}
+
 dt2df <- function(x, idcol = TRUE) {
   (data.table::setDF(
     data.table::rbindlist(x, use.names = TRUE, fill = TRUE, idcol = idcol)))
