@@ -1,11 +1,10 @@
-# tests for fungorum fxns in taxize
 context("fungorum")
 
 test_that("fungorum - fg_name_search", {
-  skip_on_cran()
-
-  aa <- fg_name_search(q = "Gymnopus", limit = 2)
-  bb <- fg_name_search(q = "Gymnopus")
+  vcr::use_cassette("fg_name_search", {
+    aa <- fg_name_search(q = "Gymnopus", limit = 2)
+    bb <- fg_name_search(q = "Gymnopus")
+  }, preserve_exact_body_bytes = TRUE)
 
   expect_is(aa, "data.frame")
   expect_is(bb, "data.frame")
@@ -20,9 +19,9 @@ test_that("fungorum - fg_name_search", {
 })
 
 test_that("fungorum - fg_epithet_search", {
-  skip_on_cran()
-
-  aa <- fg_epithet_search(q = "phalloides", limit = 2)
+  vcr::use_cassette("fg_epithet_search", {
+    aa <- fg_epithet_search(q = "phalloides", limit = 2)
+  })
 
   expect_is(aa, "data.frame")
   expect_true(any(grepl("authors", names(aa))))
@@ -31,9 +30,9 @@ test_that("fungorum - fg_epithet_search", {
 })
 
 test_that("fungorum - fg_name_by_key", {
-  skip_on_cran()
-
-  aa <- fg_name_by_key(17703)
+  vcr::use_cassette("fg_name_by_key", {
+    aa <- fg_name_by_key(17703)
+  })
 
   expect_is(aa, "data.frame")
   expect_true(any(grepl("pubplaceofpublication", names(aa))))
@@ -42,9 +41,9 @@ test_that("fungorum - fg_name_by_key", {
 })
 
 test_that("fungorum - fg_name_full_by_lsid", {
-  skip_on_cran()
-
-  aa <- fg_name_full_by_lsid("urn:lsid:indexfungorum.org:names:81085")
+  vcr::use_cassette("fg_name_full_by_lsid", {
+    aa <- fg_name_full_by_lsid("urn:lsid:indexfungorum.org:names:81085")
+  })
 
   expect_is(aa, "character")
   expect_equal(length(aa), 1)
@@ -52,23 +51,22 @@ test_that("fungorum - fg_name_full_by_lsid", {
   expect_true(grepl("1985", aa))
 })
 
-test_that("fungorum - fg_all_updated_names", {
-  skip_on_cran()
-
-  date <- as.numeric(gsub("-", "", as.character(Sys.Date()))) - 120
-  aa <- fg_all_updated_names(date = date)
-
-  expect_is(aa, "data.frame")
-  expect_gt(NROW(aa), 1)
-  expect_match(aa[1,], "indexfungorum")
-
-  date <- as.numeric(gsub("-", "", as.character(Sys.Date() + 1)))
-  expect_equal(NROW(fg_all_updated_names(date = date)), 0)
-})
+#test_that("fungorum - fg_all_updated_names", {
+#  skip_on_cran()
+#
+#  date <- as.numeric(gsub("-", "", as.character(Sys.Date()))) - 200
+#  aa <- fg_all_updated_names(date = date)
+#
+#  expect_is(aa, "data.frame")
+#  expect_gt(NROW(aa), 1)
+#  expect_match(aa[1,], "indexfungorum")
+#
+#  date <- as.numeric(gsub("-", "", as.character(Sys.Date() + 1)))
+#  expect_equal(NROW(fg_all_updated_names(date = date)), 0)
+#})
 
+# FIXME: when date injection for vcr fixed, come back to this
 test_that("fungorum - fg_deprecated_names", {
-  skip_on_cran()
-
   date <- as.numeric(gsub("-", "", as.character(Sys.Date() - 30)))
   aa <- fg_deprecated_names(date = date)
 
@@ -81,9 +79,9 @@ test_that("fungorum - fg_deprecated_names", {
 })
 
 test_that("fungorum - fg_author_search", {
-  skip_on_cran()
-
-  aa <- fg_author_search(q = "Fayod", limit = 2)
+  vcr::use_cassette("fg_author_search", {
+    aa <- fg_author_search(q = "Fayod", limit = 2)
+  }, preserve_exact_body_bytes = TRUE)
 
   expect_is(aa, "data.frame")
   expect_equal(NROW(aa), 2)
