@@ -42,13 +42,13 @@ test_that("get_wormsid fails well", {
 
   skip_on_cran()
   expect_error(get_wormsid(), "argument \"query\" is missing")
-  expect_error(get_wormsid("clam", 5),
+  expect_error(get_wormsid("clam", 5, messages = FALSE),
                "searchtype must be of class character")
   expect_error(get_wormsid("clam", "stuff", messages = FALSE),
                "'searchtype' must be one of")
-  expect_error(get_wormsid("clam", accepted = 4),
+  expect_error(get_wormsid("clam", accepted = 4, messages = FALSE),
                "accepted must be of class logical")
-  expect_error(get_wormsid("clam", ask = 4),
+  expect_error(get_wormsid("clam", ask = 4, messages = FALSE),
                "ask must be of class logical")
 })
 
